.. include:: introduction.rst

.. toctree::
   :maxdepth: 2

   installation
   gettingstarted
   using
   LICENSE
   acknowledgements
   CHANGELOG
   reference/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
